
 /*+-------------------------------------------------------+
   |          SUGI 30 Sample                               |
   |          SAS/Graph: Tips and tricks                   |
   |                                                       |
   |    NAME: Imageback.sas                                |
   |   TITLE: Create a barchart in SUGI colors             |
   |          using an image background.                   |
   | PRODUCT: GRAPH                                        |
   |                                                       |
   |   NOTES: Last Update 05Jan05                          |
   +-------------------------------------------------------+*/


%let name=image;
filename odsout '.';
goptions reset;

/*********************************************************************/
/* Get the data to graph.  Add data-tips for the bars and drill down */
/*********************************************************************/
data a;
   input SUGIs $ 1-20 area $ 21-41 percentage;
   format percentage percent7.0;
   length myhtml $500;
   /* Data tips */
   /*replace '0D'x with a blank for devices other than GIF*/
   myhtml='alt='|| quote( 'Number of times at SUGI: '||
               trim(left(sugis))||'0D'x||
               'Area of Interest: '||trim(left(area))||'0D'x||
               trim(left(put(percentage,percent7.0)))||
               ' with interest in this area ') || ' ' ||
          'href="http://support.sas.com/usergroups/sugi/sugi30/sections.html"';

   cards;
1 (once)            Latest SAS version   .47    
1 (once)            Internet             .47      
1 (once)            ODS                  .38      
1 (once)            Future direction     .36      
1 (once)            Data warehousing     .34      
1 (once)            Advanced analytics   .38      
1 (once)            e-business tools     .13      
1 (once)            Web reporting        .05      
2 to 5              Latest SAS version   .58    
2 to 5              Internet             .54      
2 to 5              ODS                  .38      
2 to 5              Future direction     .33      
2 to 5              Data warehousing     .33      
2 to 5              Advanced analytics   .21      
2 to 5              e-business tools     .18      
2 to 5              Web reporting        .14      
6 or more           Latest SAS version   .70    
6 or more           Internet             .56      
6 or more           ODS                  .55      
6 or more           Future direction     .67      
6 or more           Data warehousing     .44      
6 or more           Advanced analytics   .23      
6 or more           e-business tools     .20      
6 or more           Web reporting        .11      
;
run;

/* ----------------------------------------------------------*/     
/* Declare a macro to do the graph, for the specified device */
/* ----------------------------------------------------------*/     
%macro do_graph(dev);
   GOPTIONS DEVICE=&dev;
 
   ODS LISTING CLOSE;
   ODS HTML path=odsout body="&name._&dev..html"
            style=d3d
   ;
 
   /* This sets your image background */
   goptions iback="powerpoint.jpg" imagestyle=fit;

   goptions ftext="arial" htext=2.5pct border;

   /* Add extra blank space on all sides of graph */
   title h=15pct " ";
   title2 j=r a=-90 h=5pct " ";
   title3 j=l  a=90 h=12pct " ";
   footnote h=5pct " ";

   /* Get rid of the midpoint axis, since that's redundant with */
   /* the legend */
   axis1 label=none value=none;
   axis2 label=(f="arial/bold" j=c '% with' j=c 'interest') 
         order=(0 to .80 by .10) minor=none;
   axis3 label=(f="arial/bold" '<==  Times at SUGI') 
         value=(justify=center) offset=(8,8);  

   legend1 position=(bottom) across=4 shape=bar(2,.5) label=none frame;
 
   /*Pick colors for the bars*/
   pattern1 v=s c=cx003397;
   pattern2 v=s c=cx847f8a;
   pattern3 v=s c=cx023269;
   pattern4 v=s c=cx6d6a84;
   pattern5 v=s c=cxc99908;
   pattern6 v=s c=cxffcb08;
   pattern7 v=s c=cxcac8f4;
   pattern8 v=s c=cx066cd2;

   proc gchart data=a; 
     note height=2 font="arial/bold" color=cx003299
        move=(45,34) "Interests of SUGI attendees";
     vbar area / 
        descending 
        group=SUGIs
        subgroup=area
        /* Just chart sums since the data is pre-summarized*/
        sumvar=percentage  /* height of bar */
        legend=legend1  /* custom legend */
        maxis=axis1   /* midpoint (area) axis */
        raxis=axis2   /* response (percentage) axis */
        gaxis=axis3   /* group (SUGIs) axis */
        coutline=black
        noframe
        space=0       /* spacing between bars */
        gspace=8      /* spacing between groups of bars */
        html=myhtml   /* data tips*/
        des=""
       name="&name"; 
   run;




   quit;
   ODS HTML CLOSE;
   ODS LISTING;
%mend do_graph;
/* ---------------------------------------------------------*/     

/*run the graph for a device*/
%do_graph(gif);

/*
%do_graph(activex);
%do_graph(actximg);
%do_graph(java);
*/

