 /*+-------------------------------------------------------+
   |          SUGI 30 Sample                               |
   |          SAS/Graph: Tips and tricks                   |
   |                                                       |
   |    NAME: simplepie_style.sas                          |
   |   TITLE: Create a simple pie chart that has the slices|
   |          in the order you want them in.               |
   |          This adds to simplepie.sas by adding styles  |
   | PRODUCT: GRAPH                                        |
   |                                                       |
   |   NOTES: Last Update 05Jan05                          |
   +-------------------------------------------------------+*/

%let name=simplepie;
filename odsout '.';
goptions reset=all;

/**********************************************************************/
/* The real trick here is using a value to force the ordering of the  */
/* slices of the pie slices.  A user defined format gives the name you*/
/* really want to see.                                                */
/* Original data is in this form:                                     */
/* Republican           .25                                           */
/* Other                .04                                           */
/* Independent          .53                                           */
/* Libertarian          .06                                           */
/* Democrat             .12                                           */
/**********************************************************************/
proc format;
   /*value represents the order you want your slices in*/
   value prtyfmt
   1='Republican'
   2='Other'
   3='Independent'
   4='Libertarian'
   5='Democrat'
   ;
run;

/* change the data to use the numeric value for each party */
data a;
   format party prtyfmt.;
   format percentage percent5.0;
   input party percentage;
   cards;
1                    .25
2                    .04
3                    .53
4                    .06
5                    .12
;
run;

/* ---------------------------------------------------------*/     
/* Declare a macro to do the plot, for the specified device */
/* ---------------------------------------------------------*/     
%macro do_graph(dev,style);
   GOPTIONS DEVICE=&dev;
 
   ODS LISTING CLOSE;
   ODS HTML path=odsout body="&name._&dev._&style..html"
            style=&style
            nogfootnote
            ;

   /*NOTE:  Pattern statements and goptions statements were removed*/ 


   /*NOTE: Height changed on titles */
   title  "Break down of Talk Radio Listeners"; 
   title2 "By Political Party";
   proc gchart data=a; 
        pie3d party / 
        discrete    /*show all values*/
        sumvar=percentage
		explode=3
        value=inside   /*place on slice*/
        slice=outside  /*place outside slice*/
        noheading
        des=""
        name="&name"
        ;  
   run;


   quit;
   ODS HTML CLOSE;
   ODS LISTING;

%mend do_graph;
/* ---------------------------------------------------------*/     

/*run macro for selected devices*/



%do_graph(actximg, curve);
%do_graph(actximg, science);
%do_graph(javaimg, curve);

/*
%do_graph(activex, money);
%do_graph(java, banker);
*/

